<?php

#
# WordPress SmoothGallery plugin
# Copyright (C) 2008 Christian Schenk
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#

/**
 * Returns an array with the parameters for the SmoothGallery.
 *
 * If the parameter $defaultValues is set to true the array contains just the
 * keys and the corresponding default values. If it's set to false it contains
 * the keys along with their meta-keys which may be used in the custom field.
 */
function get_default_smoothgallery_parameters($defaultValues = true) {
	# copied from jd.gallery.js
	# -> contains the default values and the keys that may be used along with the custom field
	$parameters = array('showArrows' => array('true', 'a', 'arrows', 'showArrows'),
	                    'showCarousel' => array('false', 'c', 'carousel', 'showCarousel'), # true by default
	                    'showInfopane' => array('true', 'i', 'info', 'infoPane'),
	                    'embedLinks' => array('true', 'l', 'links', 'embedLinks'),
	                    'fadeDuration' => array(500, 'fadeDuration'),
	                    'timed' => array('false', 't', 'timed'),
	                    'delay' => array(9000, 'd', 'delay'),
	                    'preloader' => array('true', 'preloader'),
	                    'preloaderImage' => array('true', 'preloaderImage'),
	                    'preloaderErrorImage' => array('true', 'preloaderErrorImage'),
	                    /* Data retrieval */
	                    'manualData' => array('[]', 'manualData'),
	                    'populateFrom' => array('false', 'populateFrom'),
	                    'populateData' => array('true', 'populateData'),
	                    'destroyAfterPopulate' => array('true', 'destroyAfterPopulate'),
	                    'elementSelector' => array('"div.imageElement"', 'elementSelector'),
	                    'titleSelector' => array('"h3"', 'titleSelector'),
	                    'subtitleSelector' => array('"p"', 'subtitleSelector'),
	                    'linkSelector' => array('"a.open"', 'linkSelector'),
	                    'imageSelector' => array('"img.full"', 'imageSelector'),
	                    'thumbnailSelector' => array('"img.thumbnail"', 'thumbnailSelector'),
	                    'defaultTransition' => array('"fade"', 'defaultTransition'),
	                    /* InfoPane options */
	                    'slideInfoZoneOpacity' => array(0.7, 'slideInfoZoneOpacity'),
	                    'slideInfoZoneSlide' => array('true', 'slideInfoZoneSlide'),
	                    /* Carousel options */
	                    'carouselMinimizedOpacity' => array(0.4, 'carouselMinimizedOpacity'),
	                    'carouselMinimizedHeight' => array(20, 'carouselMinimizedHeight'),
	                    'carouselMaximizedOpacity' => array(0.9, 'carouselMaximizedOpacity'),
	                    'thumbHeight' => array(75, 'thumbHeight'),
	                    'thumbWidth' => array(100, 'thumbWidth'),
	                    'thumbSpacing' => array(10, 'thumbSpacing'),
	                    'thumbIdleOpacity' => array(0.2, 'thumbIdleOpacity'),
	                    'textShowCarousel' => array("'Pictures'", 'textShowCarousel'),
	                    'showCarouselLabel' => array('true', 'showCarouselLabel'),
	                    'thumbCloseCarousel' => array('true', 'thumbCloseCarousel'),
	                    'useThumbGenerator' => array('false', 'useThumbGenerator'),
	                    'thumbGenerator' => array("'resizer.php'", 'thumbGenerator'),
	                    'useExternalCarousel' => array('false', 'useExternalCarousel'),
	                    'carouselElement' => array('false', 'carouselElement'),
	                    'carouselHorizontal' => array('true', 'carouselHorizontal'),
	                    'activateCarouselScroller' => array('true',' activateCarouselScroller'),
	                    'carouselPreloader' => array('true', 'carouselPreloader'),
	                    'textPreloadingCarousel' => array("'Loading...'", 'textPreloadingCarousel'),
	                    /* CSS Classes */
	                    'baseClass' => array('jdGallery', 'baseClass'),
	                    'withArrowsClass' => array('withArrows', 'withArrowsClass'),
	                    /* Plugins: HistoryManager */
	                    'useHistoryManager' => array('false', 'useHistoryManager'),
	                    'customHistoryKey' => array('false', 'customHistoryKey'));

	# extra parameters (e.g. for the CSS)
	$parameters['height'] = array(345, 'h', 'height');
	$parameters['width'] = array(460, 'w', 'width');
	$parameters['bordercolor'] = array('000', 'b', 'border', 'bordercolor');

	# return either the default values or the meta-keys
	$tmpParameters = array();
	foreach ($parameters as $key => $value) $tmpParameters[$key] = ($defaultValues == true) ? $value[0] : array_slice($value, 1);
	return $tmpParameters;
}


/**
 * Returns an array containing the names of some extra parameters that aren't a
 * part of SmoothGallery's core parameters.
 *
 * Hint: if you add extra parameters to get_default_smoothgallery_parameters(),
 * don't forget to add them here too.
 */
function get_extra_smoothgallery_parameters() {
	return array('height', 'width', 'bordercolor');
}


/**
 * Returns the value from a string in the following format:
 * '<$param><delimiter><value>        [...]\n
 *  <$anotherparam><delimiter><value> [...]'
 * where delimiter will be either ':' or '='.
 *
 * @param string $data the string with the data
 * @param array $params the parameter we're searching for
 * @return mixed the value from the string, otherwise false
 */
function get_smoothgallery_parameter($data, $params) {
	$metas = explode("\n", $data);
	foreach ($metas as $meta) {
		foreach ($params as $param) {
			if (preg_match('/'.$param.' *[:=]{1} *(\S*)/i', $meta, $matches)) {
				if (empty($matches[1])) continue;
				return rtrim($matches[1]);
			}
		}
	}
	return false;
}


/**
 * Generates the SmoothGallery markup for an array of images.
 *
 * @returns false if the array is empty, otherwise the HTML markup
 */
function generate_markup($images/*, $thumbnail = NULL*/) {
	if (empty($images)) return false;

	$markup .= '<div id="myGallery">'."\n";
	foreach ($images as $image) {
		$markup .= '<div class="imageElement">'."\n".
		           '<h3>'.$image->title.'</h3>'."\n".
		           '<p>'.$image->description.'</p>'."\n".
		           '<a href="'.$image->url.'" title="open image" class="open"></a>'."\n".
		           '<img src="'.$image->url.'" class="full" alt="'.$image->caption.'"/>'."\n".
		           #(($thumbnail != NULL) ? '<img src="'.$image->url.'" class="thumbnail" alt="'.$image->caption.'"/>'."\n" : '').
		           '</div>'."\n";
	}
	$markup .= '</div>';
	return $markup;
}


/**
 * Returns an array with pictures attached to the current post/page. You can
 * supply the ID of another post, so you don't have to search for the images
 * attached to the current post ($post->ID) only.
 */
function get_images_for_post($postId = NULL) {
	global $wpdb, $post;
	if (!is_numeric($postId)) $postId = NULL; # sanity check
	$sql = 'SELECT post_content AS description, post_title AS title, post_excerpt AS caption, guid AS url
	        FROM '.$wpdb->posts.'
	        WHERE post_parent = '.(($postId == NULL) ? $post->ID : $postId).'
	              AND post_type = "attachment"';
	$images = $wpdb->get_results($sql);
	if (empty($images)) return "There aren't any images attached here.";

	# Reorders the images, so the image given in the request is the first image
	# in the gallery. Hint: we could have used "myGallery.goTo(<nr of image>)"
	# in the JavaScript too. This way it's currently easier though, because we
	# don't know the number of the image.
	if (!empty($_REQUEST['sgfi'])) {
		$firstImage = $_REQUEST['sgfi'];
		$tmpImages = array(); $tmpImages[] = '';
		for ($i = 0; $i < count($images); $i++) {
			if ($images[$i]->title == $firstImage) $tmpImages[0] = $images[$i];
			else $tmpImages[] = $images[$i];
		}
		$images = $tmpImages;
	}

	return $images;
}

?>
